@@ -11,14 +11,12 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Implementation of layout-aware addform for IAdding
-
-$Id: adding.py 90626 2008-08-31 05:08:26Z srichter $
-"""
-__docformat__ = "reStructuredText"
-
+"""Implementation of layout-aware addform for IAdding."""
 from z3c.form import adding
-from z3c.formui import form, layout
+
+from z3c.formui import form
+from z3c.formui import layout
+
 
 class AddForm(form.ContentTemplateMixin, layout.AddFormLayoutSupport,
               adding.AddForm):
