@@ -11,31 +11,29 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
+"""Test Setup
 """
-$Id: tests.py 72087 2007-01-18 01:03:33Z rogerineichen $
-"""
-__docformat__ = "reStructuredText"
-
 import doctest
 import unittest
+
 import z3c.form.outputchecker
 import z3c.form.testing
 
 
 def setUpZPT(test):
     z3c.form.testing.setUpZPT(test)
-    from zope.app.pagetemplate.metaconfigure import registerType
-    from zope.contentprovider.tales import TALESProviderExpression
     from z3c.macro.tales import MacroExpression
+    from zope.browserpage.metaconfigure import registerType
+    from zope.contentprovider.tales import TALESProviderExpression
     registerType('macro', MacroExpression)
     registerType('provider', TALESProviderExpression)
 
 
-def setUpZ3CPT(test):
-    z3c.form.testing.setUpZ3CPT(test)
-    from zope.component import provideUtility
-    from z3c.macro.tales import z3cpt_macro_expression
-    provideUtility(z3cpt_macro_expression, name='macro')
+# def setUpZ3CPT(test):
+#     z3c.form.testing.setUpZ3CPT(test)
+#     from z3c.macro.tales import z3cpt_macro_expression
+#     from zope.component import provideUtility
+#     provideUtility(z3cpt_macro_expression, name='macro')
 
 
 def test_suite():
@@ -44,7 +42,7 @@ def test_suite():
             'README.txt',
             setUp=setUp,
             tearDown=z3c.form.testing.tearDown,
-            optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS,
-            checker=z3c.form.outputchecker.OutputChecker(doctest))
-        #for setUp in (setUpZPT, setUpZ3CPT)]) # XXX: broken macro tests
+            optionflags=doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS,
+            checker=z3c.form.testing.outputChecker)
+        # for setUp in (setUpZPT, setUpZ3CPT)]) # XXX: broken macro tests
         for setUp in (setUpZPT, )])
